@@ -1,19 +1,19 @@
 package Sah::Schema::date::day;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [int => {
     summary => 'Day of month',
     min     => 1,
     max     => 31,
     examples => [
-        {data=>'', valid=>0},
-        {data=>1, valid=>1},
-        {data=>31, valid=>1},
-        {data=>32, valid=>0},
+        {value=>'', valid=>0},
+        {value=>1, valid=>1},
+        {value=>31, valid=>1},
+        {value=>32, valid=>0},
     ],
 }, {}];
 
@@ -33,7 +33,7 @@ Sah::Schema::date::day - Day of month
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::day (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::day (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -69,13 +69,13 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- 1  # valid
+ undef  # valid
 
- 31  # valid
+ undef  # valid
 
- 32  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
