@@ -1,9 +1,9 @@
 package Sah::Schema::date::dow_name::en;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Day-of-week name (abbreviated or full, in English)',
@@ -13,11 +13,11 @@ our $schema = [cistr => {
         qw/sunday monday tuesday wednesday thursday friday saturday/,
     ],
     examples => [
-        {data=>'', valid=>0},
-        {data=>'su', valid=>1},
-        {data=>'mOn', valid=>1},
-        {data=>'TUESDAY', valid=>1},
-        {data=>'foo', valid=>0},
+        {value=>'', valid=>0},
+        {value=>'su', valid=>1},
+        {value=>'mOn', valid=>1},
+        {value=>'TUESDAY', valid=>1},
+        {value=>'foo', valid=>0},
     ],
 }, {}];
 
@@ -37,7 +37,7 @@ Sah::Schema::date::dow_name::en - Day-of-week name (abbreviated or full, in Engl
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::dow_name::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::dow_name::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -73,15 +73,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- "su"  # valid
+ undef  # valid
 
- "mOn"  # valid
+ undef  # valid
 
- "TUESDAY"  # valid
+ undef  # valid
 
- "foo"  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
