@@ -1,19 +1,19 @@
 package Sah::Schema::date::hour;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [int => {
     summary => 'Hour of day',
     min     => 0,
     max     => 23,
     examples => [
-        {data=>'', valid=>0},
-        {data=>0, valid=>1},
-        {data=>23, valid=>1},
-        {data=>24, valid=>0},
+        {value=>'', valid=>0},
+        {value=>0, valid=>1},
+        {value=>23, valid=>1},
+        {value=>24, valid=>0},
     ],
 }, {}];
 
@@ -33,7 +33,7 @@ Sah::Schema::date::hour - Hour of day
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::hour (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::hour (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -69,13 +69,13 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- 0  # valid
+ undef  # valid
 
- 23  # valid
+ undef  # valid
 
- 24  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
