@@ -1,9 +1,9 @@
 package Sah::Schema::date::month_name::en;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Month name (abbreviated or full, in English)',
@@ -12,13 +12,13 @@ our $schema = [cistr => {
         qw/january february march april june july august september october november december/,
     ],
     examples => [
-        {data=>'', valid=>0},
-        {data=>1, valid=>0},
-        {data=>'jan', valid=>1},
-        {data=>'FeB', valid=>1},
-        {data=>'March', valid=>1},
-        {data=>'foo', valid=>0},
-        {data=>13, valid=>0},
+        {value=>'', valid=>0},
+        {value=>1, valid=>0},
+        {value=>'jan', valid=>1},
+        {value=>'FeB', valid=>1},
+        {value=>'March', valid=>1},
+        {value=>'foo', valid=>0},
+        {value=>13, valid=>0},
     ],
 }, {}];
 
@@ -38,7 +38,7 @@ Sah::Schema::date::month_name::en - Month name (abbreviated or full, in English)
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -74,19 +74,19 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- 1  # INVALID
+ undef  # INVALID
 
- "jan"  # valid
+ undef  # valid
 
- "FeB"  # valid
+ undef  # valid
 
- "March"  # valid
+ undef  # valid
 
- "foo"  # INVALID
+ undef  # INVALID
 
- 13  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
