@@ -1,20 +1,20 @@
 package Sah::Schema::date::second;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [int => {
     summary => 'Second of minute',
     min     => 0,
     max     => 60,
     examples => [
-        {data=>'', valid=>0},
-        {data=>0, valid=>1},
-        {data=>59, valid=>1},
-        {data=>60, valid=>1},
-        {data=>61, valid=>0},
+        {value=>'', valid=>0},
+        {value=>0, valid=>1},
+        {value=>59, valid=>1},
+        {value=>60, valid=>1},
+        {value=>61, valid=>0},
     ],
 }, {}];
 
@@ -34,7 +34,7 @@ Sah::Schema::date::second - Second of minute
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::second (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::second (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -70,15 +70,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- 0  # valid
+ undef  # valid
 
- 59  # valid
+ undef  # valid
 
- 60  # valid
+ undef  # valid
 
- 61  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
