@@ -1,9 +1,9 @@
 package Sah::Schema::date::tz_name;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [str => {
     summary => 'Timezone name',
@@ -15,7 +15,7 @@ our $schema = [str => {
         Complete::TZ::complete_tz(word => $args{word});
     },
     examples => [
-        {data=>'Asia/Jakarta', valid=>1},
+        {value=>'Asia/Jakarta', valid=>1},
     ],
 }, {}];
 
@@ -35,7 +35,7 @@ Sah::Schema::date::tz_name - Timezone name
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- "Asia/Jakarta"  # valid
+ undef  # valid
 
 =head1 DESCRIPTION
 
