@@ -1,9 +1,9 @@
 package Sah::Schema::date::tz_offset;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 BEGIN {
 
@@ -59,18 +59,18 @@ _
         );
     },
     examples => [
-        {data=>'', valid=>0},
-        {data=>'UTC', valid=>1, res=>0},
-        {data=>'3600', valid=>1, res=>3600},
-        {data=>'-43200', valid=>1, res=>-43200},
-        {data=>'-12', valid=>1, res=>-12*3600},
-        {data=>'-1200', valid=>1, res=>-12*3600},
-        {data=>'-12:00', valid=>1, res=>-12*3600},
-        {data=>'UTC-12', valid=>1, res=>-12*3600},
-        {data=>'UTC-1200', valid=>1, res=>-12*3600},
-        {data=>'UTC+12:45', valid=>1, res=>+12.75*3600},
-        {data=>'UTC-13', valid=>0},
-        {data=>'UTC+12:01', valid=>0, summary=>'Unknown offset'},
+        {value=>'', valid=>0},
+        {value=>'UTC', valid=>1, res=>0},
+        {value=>'3600', valid=>1, res=>3600},
+        {value=>'-43200', valid=>1, res=>-43200},
+        {value=>'-12', valid=>1, res=>-12*3600},
+        {value=>'-1200', valid=>1, res=>-12*3600},
+        {value=>'-12:00', valid=>1, res=>-12*3600},
+        {value=>'UTC-12', valid=>1, res=>-12*3600},
+        {value=>'UTC-1200', valid=>1, res=>-12*3600},
+        {value=>'UTC+12:45', valid=>1, res=>+12.75*3600},
+        {value=>'UTC-13', valid=>0},
+        {value=>'UTC+12:01', valid=>0, summary=>'Unknown offset'},
     ],
 }, {}];
 
@@ -90,7 +90,7 @@ Sah::Schema::date::tz_offset - Timezone offset in seconds from UTC
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::date::tz_offset (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+This document describes version 0.011 of Sah::Schema::date::tz_offset (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -126,29 +126,29 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- "UTC"  # valid, becomes 0
+ undef  # valid, becomes 0
 
- 3600  # valid, becomes 3600
+ undef  # valid, becomes 3600
 
- -43200  # valid, becomes -43200
+ undef  # valid, becomes -43200
 
- -12  # valid, becomes -43200
+ undef  # valid, becomes -43200
 
- -1200  # valid, becomes -43200
+ undef  # valid, becomes -43200
 
- "-12:00"  # valid, becomes -43200
+ undef  # valid, becomes -43200
 
- "UTC-12"  # valid, becomes -43200
+ undef  # valid, becomes -43200
 
- "UTC-1200"  # valid, becomes -43200
+ undef  # valid, becomes -43200
 
- "UTC+12:45"  # valid, becomes 45900
+ undef  # valid, becomes 45900
 
- "UTC-13"  # INVALID
+ undef  # INVALID
 
- "UTC+12:01"  # INVALID (Unknown offset)
+ undef  # INVALID (Unknown offset)
 
 =head1 DESCRIPTION
 
